==> duiba-live-activity-center-api-0.0.3-sources.jar: cn/com/duiba/live/activity/center/api/dto/clue/LiveRedPacketReceiveDto.java <==
package cn.com.duiba.live.activity.center.api.dto.clue;

import cn.com.duiba.live.activity.center.api.enums.live.LiveRedPacketReciveRewardTypeEnum;
import cn.com.duiba.live.activity.center.api.enums.live.LiveRedPacketReceiveStatusEnum;
import cn.com.duiba.live.activity.center.api.enums.live.LiveRedReceiveFailCodeEnum;
import cn.com.duiba.live.activity.center.api.enums.red.LiveRedReceiveTypeEnum;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 直播红包领取记录
 * @author kjj mybatis generator
 * @date 2020-04-02
 */
@Data
public class LiveRedPacketReceiveDto implements Serializable {

    private static final long serialVersionUID = 15858340744369906L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 直播ID
     */
    private Long liveId;

    /**
     * 红包配置ID
     */
    private Long confRedPacketId;

    /**
     * 直播访客userId
     */
    private Long liveVisitorId;

    /**
     * 代理人ID
     */
    private Long agentId;

    /**
     * 红包金额
     */
    private Integer amount;

    /**
     * 领取状态：1-未领取，2-领取中，3-领取成功，4-领取失败
     * @see LiveRedPacketReceiveStatusEnum
     */
    private Integer receiveStatus;

    /**
     * 领取时间
     */
    private Date receiveTime;

    /**
     * 申请商户号的appid或商户号绑定的appid
     */
    private String appId;

    /**
     * 用户的标识，对公众号唯一
     */
    private String openId;

    /**
     * 用户真实ip
     */
    private String clientIp;

    /**
     * 错误码信息
     */
    private String errCode;

    /**
     * 失败原因
     * @see LiveRedReceiveFailCodeEnum
     */
    private Integer failCode;

    /**
     * 红包类型
     * @see LiveRedReceiveTypeEnum
     */
    private Integer receiveType;

    /**
     * 业务方用户ID
     */
    private String bizUserId;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 红包发放来源业务类型
     * @see LiveRedPacketReciveRewardTypeEnum
     */
    private Integer originType= LiveRedPacketReciveRewardTypeEnum.DEFAULT.getCode();
}

==> duiba-live-activity-center-api-0.0.6-sources.jar: cn/com/duiba/live/activity/center/api/dto/clue/LiveRedPacketReceiveDto.java <==
package cn.com.duiba.live.activity.center.api.dto.clue;

import cn.com.duiba.live.activity.center.api.enums.live.LiveRedPacketReciveRewardTypeEnum;
import cn.com.duiba.live.activity.center.api.enums.live.LiveRedPacketReceiveStatusEnum;
import cn.com.duiba.live.activity.center.api.enums.live.LiveRedReceiveFailCodeEnum;
import cn.com.duiba.live.activity.center.api.enums.red.LiveRedReceiveTypeEnum;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 直播红包领取记录
 * @author kjj mybatis generator
 * @date 2020-04-02
 */
@Data
public class LiveRedPacketReceiveDto implements Serializable {

    private static final long serialVersionUID = 15858340744369906L;
    /**
     * 主键
     */
    private Long id;

    /**
     * 直播ID
     */
    private Long liveId;

    /**
     * 红包配置ID
     */
    private Long confRedPacketId;

    /**
     * 直播访客userId
     */
    private Long liveVisitorId;

    /**
     * 代理人ID
     */
    private Long agentId;

    /**
     * 红包金额
     */
    private Integer amount;

    /**
     * 领取状态：领取状态：1-未领取，2-领取中，3-微信中间状态，4-领取成功,5-领取失败
     * @see LiveRedPacketReceiveStatusEnum
     */
    private Integer receiveStatus;

    /**
     * 领取时间
     */
    private Date receiveTime;

    /**
     * 业务方订单号
     */
    private String bizTradeNo;

    /**
     * 申请商户号的appid或商户号绑定的appid
     */
    private String appId;

    /**
     * 用户的标识，对公众号唯一
     */
    private String openId;

    /**
     * 用户真实ip
     */
    private String clientIp;

    /**
     * 错误码信息
     */
    private String errCode;

    /**
     * 失败原因
     * @see LiveRedReceiveFailCodeEnum
     */
    private Integer failCode;

    /**
     * 红包类型
     * @see LiveRedReceiveTypeEnum
     */
    private Integer receiveType;

    /**
     * 业务方用户ID
     */
    private String bizUserId;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 更新时间
     */
    private Date gmtModified;

    /**
     * 红包发放来源业务类型
     * @see LiveRedPacketReciveRewardTypeEnum
     */
    private Integer originType= LiveRedPacketReciveRewardTypeEnum.DEFAULT.getCode();
}
